@@ -1,12 +1,14 @@
 #******************************************************************************
-# $Id: POP3Client.pm,v 1.15 1996/12/04 14:15:05 sdowd Exp $
+# $Id: POP3Client.pm,v 1.16 1998/09/07 14:15:05 ssd Exp $
 #
 # Description:  POP3Client module - acts as interface to POP3 server
-# Author:       Sean Dowd <ssd@mmts.eds.com>
+# Author:       Sean Dowd <ssd@ticnet.com>
 #
 # Copyright (c) 1995,1996 Electonic Data Systems, Inc.  All rights reserved.
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
+#
+# Versions 1.16 and later.
 #******************************************************************************
 
 package Mail::POP3Client;
@@ -156,7 +158,7 @@ Set/Return the current port number.
 
 =head1 AUTHOR
 
-Sean Dowd <ssd@mmts.eds.com>
+Sean Dowd <ssd@ticnet.com>
 
 =head1 COPYRIGHT
 
@@ -183,8 +185,8 @@ use Socket qw(PF_INET SOCK_STREAM AF_INET);
 $sockaddr = 'S n a4 x8';      # shouldn't this be in Socket.pm?
 $fhcnt = 0;                   # for creating unique filehandles
 
-$ID =q( $Id: POP3Client.pm,v 1.15 1996/12/04 14:15:05 sdowd Exp $ );
-$VERSION = substr q$Revision: 1.15 $, 10;
+$ID =q( $Id: POP3Client.pm,v 1.16 1998/09/07 14:15:05 ssd Exp $ );
+$VERSION = substr q$Revision: 1.16 $, 10;
 
 #******************************************************************************
 #* constructor
@@ -210,9 +212,10 @@ sub new
 		ADDR => "",
 		STATE => 'DEAD',
 		MESG => 'OK',
-		EOL => "\r\n",
+		EOL => "\015\012",
 	}, $name;
 
+	$/ = $me->EOL();
 	if ($me->User($user) and $me->Pass($pass) and 
 		$me->Host($host) and $me->Port($port)) {
 		$me->Connect();
@@ -425,8 +428,8 @@ sub Connect
 
 	select((select($s) , $| = 1)[0]);  # autoflush
 
-	$msg = <$s> or $me->Message("Could not read") and return 0;
-	chop $msg;
+	defined($msg = <$s>) or $me->Message("Could not read") and return 0;
+	chomp $msg;
 	$me->Message($msg);
 	$me->State('AUTHORIZATION');
 
@@ -442,19 +445,19 @@ sub Login
 	my $me = shift;
 	my $s = $me->{SOCK};
 	print $s "USER " , $me->User , $me->EOL;
-	$_ = <$s>;
-	chop;
-	$me->Message($_);
-	/^\+/ or $me->Message("USER failed: $_") and $me->State('AUTHORIZATION')
+	my $line = <$s>;
+	chomp $line;
+	$me->Message($line);
+	$line =~ /^\+/ or $me->Message("USER failed: $line") and $me->State('AUTHORIZATION')
 		and return 0;
 
 	print $s "PASS " , $me->Pass , $me->EOL;
-	$_ = <$s>;
-	chop;
-	$me->Message($_);
-	/^\+/ or $me->Message("PASS failed: $_") and $me->State('AUTHORIZATION')
+	$line = <$s>;
+	chomp $line;
+	$me->Message($line);
+	$line =~ /^\+/ or $me->Message("PASS failed: $line") and $me->State('AUTHORIZATION')
 		and return 0;
-	/^\+OK \S+ has (\d+) /i and $me->Count($1);
+	$line =~ /^\+OK \S+ has (\d+) /i and $me->Count($1);
 
 	$me->State('TRANSACTION');
 
@@ -474,16 +477,16 @@ sub Head
 
 	$me->Debug and print "TOP $num 0\n";
 	print $s "TOP $num 0", $me->EOL;
-	$_ = <$s>;
-	$me->Debug and print;
-	chop;
-	/^\+OK/ or $me->Message("Bad return from TOP: $_") and return '';
-	/^\+OK (\d+) / and $buflen = $1;
+	my $line = <$s>;
+	$me->Debug and print $line;
+	chomp $line;
+	$line =~ /^\+OK/ or $me->Message("Bad return from TOP: $line") and return '';
+	$line =~ /^\+OK (\d+) / and $buflen = $1;
 	
 	do {
-		$_ = <$s>;
-		/^\s*$|^\.\s*$/ or $header .= $_;
-	} until /^\.\s*$/;
+		$line = <$s>;
+		$line =~ /^\s*$|^\.\s*$/ or $header .= $line;
+	} until $line =~ /^\.\s*$/;
 
 	return wantarray ? split(/\r?\n/, $header) : $header;
 } # end Head
@@ -500,16 +503,16 @@ sub HeadAndBody
 
 	$me->Debug and print "RET $num\n";
 	print $s "RETR $num", $me->EOL;
-	$_ = <$s>;
-	$me->Debug and print;
-	chop;
-	/^\+OK/ or $me->Message("Bad return from RETR: $_") and return '';
-	/^\+OK (\d+) / and $buflen = $1;
+	my $line = <$s>;
+	$me->Debug and print $line;
+	chomp $line;
+	$line =~ /^\+OK/ or $me->Message("Bad return from RETR: $line") and return '';
+	$line =~ /^\+OK (\d+) / and $buflen = $1;
 	
 	do {
-		$_ = <$s>;
-		/^\.\s*$/ or $mandb .= $_;
-	} until /^\.\s*$/;
+		$line = <$s>;
+		$line =~ /^\.\s*$/ or $mandb .= $line;
+	} until $line =~ /^\.\s*$/;
 
 	return wantarray ? split(/\r?\n/, $mandb) : $mandb;
 
@@ -527,21 +530,21 @@ sub Body
 	
 	$me->Debug and print "RET $num\n";
 	print $s "RETR $num", $me->EOL;
-	$_ = <$s>;
-	$me->Debug and print;
-	chop;
-	/^\+OK/ or $me->Message("Bad return from RETR: $_") and return '';
-	/^\+OK (\d+) / and $buflen = $1;
+	my $line = <$s>;
+	$me->Debug and print $line;
+	chomp $line;
+	$line =~ /^\+OK/ or $me->Message("Bad return from RETR: $line") and return '';
+	$line =~ /^\+OK (\d+) / and $buflen = $1;
 	
 	# skip the header
 	do {
-		$_ = <$s>;
-	} until /^\s*$/;
+		$line = <$s>;
+	} until $line =~ /^\s*$/;
 
 	do {
-		$_ = <$s>;
-		/^\.\s*$/ or $body .= $_;
-	} until /^\.\s*$/;
+		$$line = <$s>;
+		$line =~ /^\.\s*$/ or $body .= $line;
+	} until $line =~ /^\.\s*$/;
 
 	return wantarray ? split(/\r?\n/, $body) : $body;
    
@@ -556,9 +559,9 @@ sub POPStat {
 
 	$me->Debug and carp "POP3: POPStat";
 	print $s "STAT", $me->EOL;
-	$_ = <$s>;
-	/^\+OK/ or $me->Message("STAT failed: $_") and return 0;
-	/^\+OK (\d+) (\d+)/ and $me->Count($1), $me->Size($2);
+	my $line = <$s>;
+	$line =~ /^\+OK/ or $me->Message("STAT failed: $line") and return 0;
+	$line =~ /^\+OK (\d+) (\d+)/ and $me->Count($1), $me->Size($2);
 
     return $me->Count();
 }
@@ -578,17 +581,17 @@ sub List {
 
 	$me->Debug and carp "POP3: List $num";
 	print $s "LIST $num", $me->EOL;
-	$_ = <$s>;
-	/^\+OK/ or $me->Message("$_") and return;
+	my $line = <$s>;
+	$line =~ /^\+OK/ or $me->Message("$line") and return;
 	if ($num) {
-		$_ =~ s/^\+OK\s*//;
-		return $_;
+		$line =~ s/^\+OK\s*//;
+		return $line;
 	}
-	while($_ = <$s>) {
-		/^\.\s*$/ and last;
-		$ret .= $_;
-		chop;
-		push(@retarray, $_);
+	while( defined( $line = <$s> ) ) {
+		$line =~ /^\.\s*$/ and last;
+		$ret .= $line;
+		chomp $line;
+		push(@retarray, $line);
 	}
 	if ($ret) {
 		return wantarray ? @retarray : $ret;
@@ -612,15 +615,15 @@ sub Retrieve {
 
 	$me->Debug and print STDERR "DEBUG: RETR $num", $me->EOL;
 	print $s "RETR $num", $me->EOL;
-	$_ = <$s>;
-	/^\+OK\s*/ or $me->Message($_) and return;
+	my $line = <$s>;
+	$line =~ /^\+OK\s*/ or $me->Message($line) and return;
 
-	while($_ = <$s>) {
-		$me->Debug and print STDERR "DEBUG: $_";
-		/^\.\s*$/ and last;
-		$ret .= $_;
-		chop;
-		push(@retarray, $_);
+	while( defined( $line = <$s> ) ) {
+		$me->Debug and print STDERR "DEBUG: $line";
+		$line =~ /^\.\s*$/ and last;
+		$ret .= $line;
+		chomp $line;
+		push(@retarray, $line);
 	}
 	if ($ret) {
 		return wantarray ? @retarray : $ret;
@@ -638,9 +641,9 @@ sub Last {
 	my $s = $me->Socket;
 	
 	print $s "LAST", $me->EOL;
-	$_ = <$s>;
+	my $line = <$s>;
 	
-	/\+OK (\d+)\s*$/ and return $1;
+	$line =~ /\+OK (\d+)\s*$/ and return $1;
 }
 
 #******************************************************************************
@@ -651,8 +654,8 @@ sub Reset {
 	
 	my $s = $me->Socket;
 	print $s "RSET", $me->EOL;
-	$_ = <$s>;
-	/\+OK .*$/ and return 1;
+	my $line = <$s>;
+	$line =~ /\+OK .*$/ and return 1;
 	return 0;
 }
 
@@ -665,9 +668,9 @@ sub Delete {
 
 	my $s = $me->Socket;
 	print $s "DELE $num",  $me->EOL;
-	$_ = <$s>;
-	$me->Message($_);
-	/^\+OK / && return 1;
+	my $line = <$s>;
+	$me->Message($line);
+	$line =~ /^\+OK / && return 1;
 	return 0;
 }
 
